@@ -1,7 +1,7 @@
 package Config::IOD::Document;
 
-our $DATE = '2016-03-03'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2016-12-27'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010;
 use strict;
@@ -371,16 +371,19 @@ sub _get_section_line_range {
     my $start;
     for my $line (@{ $self->{_parsed} }) {
         $linum++;
-        $start = $linum if !$start && $cur_section eq $name;
         if ($line->[COL_TYPE] eq 'S') {
             $cur_section = $line->[COL_S_SECTION];
-            do { push @res, [$start, $linum]; undef $start } if $start;
-            $start = $linum+1 if !$start && $cur_section eq $name;
+            if ($cur_section eq $name) {
+                $start = $linum+1;
+                $res[-1][1] = $linum if @res && !defined $res[-1][1];
+                push @res, [$start, undef];
+            } else {
+                $res[-1][1] = $linum if @res;
+                last if @res && !$opts->{all};
+            }
         }
-        goto L1 if @res && !$opts->{all};
     }
-    $linum = $start if $start && $linum < $start;
-    push @res, [$start, $linum] if $start;
+    $res[-1][1] = $linum+1 if @res && !defined($res[-1][1]);
 
   L1:
     if ($opts->{all}) { return @res } else { return $res[0] }
@@ -781,7 +784,7 @@ Config::IOD::Document - Represent IOD document
 
 =head1 VERSION
 
-This document describes version 0.29 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-03-03.
+This document describes version 0.30 of Config::IOD::Document (from Perl distribution Config-IOD), released on 2016-12-27.
 
 =head1 SYNOPSIS
 
@@ -1120,7 +1123,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Config-IOD
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Config-IOD>.
+Source repository is at L<https://github.com/sharyanto/perl-Config-IOD>.
 
 =head1 BUGS
 
